@@ -11,7 +11,7 @@ from django.conf import settings
 from django.db.models import Count,Sum,Q
 
 from picklefield.fields import PickledObjectField
-
+import caching.base
 # Create your models here.
 
 
@@ -83,6 +83,8 @@ class Speaker(models.Model):
     F2center = models.FloatField(blank=True,null=True)
     AvgSpeakingRate = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s' % (self.Number,)
 
@@ -167,6 +169,8 @@ class Dialog(models.Model):
     Speaker = models.ForeignKey(Speaker)
     Number = models.CharField(max_length=10)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s%s' % (self.Speaker,self.Number)
 
@@ -226,6 +230,8 @@ class SegmentType(models.Model):
     Nasal = models.BooleanField()
     Vowel = models.BooleanField()
 
+    objects = caching.base.CachingManager()
+
     def isSyllabic(self):
         return self.Syllabic
 
@@ -252,6 +258,8 @@ class Underlying(models.Model):
     Ordering = models.IntegerField()
     Stressed = models.IntegerField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getStrTrans(self):
         if self.Stressed is None:
             return str(self.SegmentType).upper()
@@ -267,7 +275,7 @@ class SegmentToken(models.Model):
     End = models.FloatField()
     Stressed = models.NullBooleanField()
 
-    objects = STManager()
+    objects = caching.base.CachingManager()
 
     def __unicode__(self):
         return u'%s' % unicode(self.SegmentType)
@@ -283,6 +291,8 @@ class Category(models.Model):
     Description = models.CharField(max_length=250)
     CategoryType = models.CharField('Category type',max_length=100)
 
+    objects = caching.base.CachingManager()
+
     def isContent(self):
         if self.CategoryType == 'Content':
             return True
@@ -297,6 +307,8 @@ class PrevCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -315,6 +327,8 @@ class FollCondProbs(models.Model):
     Count = models.IntegerField(blank=True,null=True)
     Prob = models.FloatField(blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def getProb(self):
         if self.Prob is not None:
             return self.Prob
@@ -340,6 +354,8 @@ class WordType(models.Model):
     CVSkel = models.CharField(max_length=100,blank=True,null=True)
     StressVowel = models.CharField(max_length=10,blank=True,null=True)
 
+    objects = caching.base.CachingManager()
+
     def __unicode__(self):
         return u'%s' % self.Label
 
@@ -523,7 +539,7 @@ class WordToken(models.Model):
     Ceiling = models.IntegerField(blank=True,null=True)
     Output = PickledObjectField(null=True)
 
-    objects = WTManager()
+    objects = caching.base.CachingManager()
 
     def __unicode__(self):
         return u'%s' % unicode(self.WordType)
